#!/usr/bin/php
<?php 
$dbhost = "127.0.0.1:3306";
$dbuser = "root";
$dbpass = "n03ntry";
$conn = mysql_connect($dbhost, $dbuser, $dbpass) or die                      ('Error connecting to mysql');
$dbname = 'koha';
mysql_select_db($dbname);
$sql = "DELETE FROM bibliocovers WHERE coverlocation='none'";
mysql_query($sql);
?>

